from abqpy.decorators import abaqus_class_doc
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class HistoryVariable:
    """The HistoryVariable object stores history data.

    .. note:: 
        This object can be accessed by::

            import visualization
            session.odbData[name].historyVariables[i]
    """

    #: A String specifying the history request label. This String is read-only.
    name: str = ""

    #: A String specifying the legend text. This String is read-only.
    legendLabel: str = ""

    #: A tuple of (String, Int, SymbolicConstant) tuples specifying the steps. This sequence is
    #: read-only. Each inner sequence contains the following elements:*stepLabel*: A String
    #: specifying the step label. *stepNumber*: An Int specifying the step
    #: number. *procedureDomain*: A SymbolicConstant specifying the analysis type of the step,
    #: which can have these values: “TIME,” “FREQUENCY,” or “MODAL.”
    steps: SymbolicConstant = None



import typing

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class BackwardCompatibility:
    """The BackwardCompatibility object enables the user to control access to deprecated
    commands in the Abaqus Scripting Interface and to collect data on which deprecated
    commands have been used. This enables the user to check that no deprecated methods,
    members, or arguments have been used. Data are recorded on any deprecated members,
    methods, or arguments that are used.
    The BackwardCompatibility object has no constructor. The abaqus module and the odbAccess
    module each have a member named backwardCompatibility.
    By default, the value of the **includeDeprecated** member is ON, and Abaqus will execute a
    script containing deprecated commands with no indication that you should update the
    script. You can do either of the following to change the value of the
    **includeDeprecated** member and to determine which commands have been deprecated:
    
    - From the command line interface in Abaqus/CAE or from an Abaqus Scripting Interface
      script that is run from within Abaqus/CAE, use the following command::

          backwardCompatibility.setValues(includeDeprecated=OFF)

    - From an Abaqus Scripting Interface script that is run using `abaqus python` at the
      system prompt, use the following two commands::

          from odbAccess import *
          backwardCompatibility.setValues(includeDeprecated=OFF)

    In addition, the BackwardCompatibility object provides tools to assist you in
    determining the deprecated commands that have been used. For example, to determine the
    deprecated commands used in the script createLug.py, use the following commands::2

        backwardCompatibility.resetDeprecatedMethodsUsed()
        backwardCompatibility.resetDeprecatedMembersUsed()
        backwardCompatibility.resetDeprecatedArgsUsed()
        execfile('createLug.py')
        print backwardCompatibility.getDeprecatedMethodsUsed()
        print backwardCompatibility.getDeprecatedMembersUsed()
        print backwardCompatibility.getDeprecatedArgsUsed()

    .. note:: 
        This object can be accessed by::

            backwardCompatibility
    """

    #: A Boolean specifying whether deprecated members, methods, and arguments can be seen and
    #: used. Possible values are ON and OFF. The default value is ON.
    includeDeprecated: Boolean = ON

    #: A Boolean specifying whether a warning is displayed after running a script that contains
    #: deprecated commands. The default value is True.
    reportDeprecated: Boolean = True

    #: A Boolean specifying whether the keys and indices are included in the report that is
    #: displayed when **reportDeprecated** is True. The default value is False.
    showKeysInReport: Boolean = False

    @abaqus_method_doc
    def getDeprecatedMethodsUsed(self):
        """This method returns a list of deprecated methods used since the last call to
        resetDeprecatedMethodsUsed.

        Returns
        -------
        typing.List[str]
            A list of Strings.
        """
        ...

    @abaqus_method_doc
    def getDeprecatedArgsUsed(self):
        """This method returns a list of deprecated arguments used since the last call to
        resetDeprecatedArgsUsed.

        Returns
        -------
        typing.List[str]
            A list of Strings.
        """
        ...

    @abaqus_method_doc
    def resetDeprecatedMethodsUsed(self):
        """This method clears the list of deprecated methods used."""
        ...

    @abaqus_method_doc
    def resetDeprecatedArgsUsed(self):
        """This method clears the list of deprecated arguments used."""
        ...

    @abaqus_method_doc
    def setValues(
        self,
        includeDeprecated: Boolean = ON,
        reportDeprecated: Boolean = True,
        showKeysInReport: Boolean = False,
    ):
        """This method modifies the BackwardCompatibility object.

        Parameters
        ----------
        includeDeprecated
            A Boolean specifying whether deprecated members, methods, and arguments can be seen and
            used. The default value is ON.
        reportDeprecated
            A Boolean specifying whether a warning is displayed after running a script that contains
            deprecated commands. The default value is True.
        showKeysInReport
            A Boolean specifying whether the keys and indices are included in the report that is
            displayed when **reportDeprecated** is True. The default value is False.
        """
        ...



from abqpy.decorators import abaqus_class_doc
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class DGOrientationOptions:
    """The DGOrientationOptions object stores values and attributes associated with a material
    orientation plot. The DGOrientationOptions object has no constructor command. Abaqus
    creates an *odbDisplayOptions.materialOrientationOptions* member when a display group
    instance is created, using values from *odbDisplay.materialOrientationOptions*.

    .. note:: 
        This object can be accessed by::

            session.viewports[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.materialOrientationOptions
            session.viewports[name].layers[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.materialOrientationOptions
            session.viewports[name].layers[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.materialOrientationOptions
            session.viewports[name].layers[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.materialOrientationOptions
            session.viewports[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.materialOrientationOptions
            session.viewports[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.materialOrientationOptions
    """

    #: A Boolean specifying whether axis 1 of the material orientation triad should be
    #: displayed. The default value is ON.
    showAxis1: Boolean = ON

    #: A Boolean specifying whether axis 2 of the material orientation triad should be
    #: displayed. The default value is ON.
    showAxis2: Boolean = ON

    #: A Boolean specifying whether axis 3 of the material orientation triad should be
    #: displayed. The default value is ON.
    showAxis3: Boolean = ON

    #: A Float specifying the size of the material orientation triad. The default value is 6.0.
    symbolSize: float = 6

    #: A SymbolicConstant specifying the thickness of the material orientation triad. Possible
    #: values are VERY_THIN, THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    lineThickness: SymbolicConstant = VERY_THIN

    #: A SymbolicConstant specifying the orientation used for composites. Possible values are
    #: PLY and LAYUP. The default value is PLY.
    orientation: SymbolicConstant = PLY

    #: A SymbolicConstant specifying the arrowhead style for the material orientation triad.
    #: Possible values are NONE, FILLED, and WIRE. The default value is NONE.
    arrowheadStyle: SymbolicConstant = NONE

    #: A SymbolicConstant specifying the scaling basis for the material orientation triad.
    #: Possible values are MODEL_SIZE and SCREEN_SIZE. The default value is MODEL_SIZE.
    scaleMode: SymbolicConstant = MODEL_SIZE

    #: A String specifying the color of axis 1 of the material orientation triad. The default
    #: value is "Cyan".
    axis1Color: str = ""

    #: A String specifying the color of axis 2 of the material orientation triad. The default
    #: value is "Yellow".
    axis2Color: str = ""

    #: A String specifying the color of axis 3 of the material orientation triad. The default
    #: value is "Red".
    axis3Color: str = ""



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .ContactProperty import ContactProperty
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class AcousticImpedanceProp(ContactProperty):
    """The AcousticImpedanceProp object is an interaction property that defines the properties
    referred to by an AcousticImpedance object.
    The AcousticImpedanceProp object is derived from the InteractionProperty object.

    .. note:: 
        This object can be accessed by::

            import interaction
            mdb.models[name].interactionProperties[name]

        The corresponding analysis keywords are:

        - IMPEDANCE PROPERTY
    """

    #: A String specifying the interaction property repository key.
    name: str

    #: A SymbolicConstant specifying the type of tabular data to be defined. Possible values
    #: are IMPEDANCE and ADMITTANCE.
    tableType: SymbolicConstant

    #: A sequence of sequences of Floats specifying acoustic impedance properties.If
    #: **tableType** = IMPEDANCE, each sequence of the table data specifies:The real part of the
    #: complex impedance.The imaginary part of the complex impedance.Frequency, if the data
    #: depend on frequency.If **tableType** = ADMITTANCE, each sequence of the table data
    #: specifies:The real part of the complex admittance.The imaginary part of the complex
    #: admittance.Frequency, if the data depend on frequency.
    table: tuple

    #: A Boolean specifying whether the **table** data depend on frequency. The default value is
    #: OFF.
    frequencyDependency: Boolean = OFF

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        tableType: SymbolicConstant,
        table: tuple,
        frequencyDependency: Boolean = OFF,
    ):
        """This method creates an AcousticImpedanceProp object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].AcousticImpedanceProp

        Parameters
        ----------
        name
            A String specifying the interaction property repository key.
        tableType
            A SymbolicConstant specifying the type of tabular data to be defined. Possible values
            are IMPEDANCE and ADMITTANCE.
        table
            A sequence of sequences of Floats specifying acoustic impedance properties.If
            **tableType** = IMPEDANCE, each sequence of the table data specifies:The real part of the
            complex impedance.The imaginary part of the complex impedance.Frequency, if the data
            depend on frequency.If **tableType** = ADMITTANCE, each sequence of the table data
            specifies:The real part of the complex admittance.The imaginary part of the complex
            admittance.Frequency, if the data depend on frequency.
        frequencyDependency
            A Boolean specifying whether the **table** data depend on frequency. The default value is
            OFF.

        Returns
        -------
        AcousticImpedanceProp
            An :py:class:`~abaqus.Interaction.AcousticImpedanceProp.AcousticImpedanceProp` object.
        """
        super().__init__(name)

    @abaqus_method_doc
    def setValues(self, frequencyDependency: Boolean = OFF):
        """This method modifies the AcousticImpedanceProp object.

        Parameters
        ----------
        frequencyDependency
            A Boolean specifying whether the **table** data depend on frequency. The default value is
            OFF.
        """
        ...



from abqpy.decorators import abaqus_class_doc
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class DGSymbolOptions:
    """The DGSymbolOptions object stores values and attributes associated with a symbol plot.
    The DGSymbolOptions object has no constructor command. Abaqus creates an
    *odbDisplayOptions.symbolOptions* member when a display group instance is created, using
    values from *odbDisplay.symbolOptions*.

    .. note:: 
        This object can be accessed by::

            session.viewports[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
            session.viewports[name].layers[name].assemblyDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
            session.viewports[name].layers[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
            session.viewports[name].layers[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
            session.viewports[name].odbDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
            session.viewports[name].partDisplay.displayGroupInstances[name].odbDisplayOptions.symbolOptions
    """

    #: A SymbolicConstant specifying the vector line thickness. Possible values are VERY_THIN,
    #: THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    vectorLineThickness: SymbolicConstant = VERY_THIN

    #: A SymbolicConstant specifying the vector color method. Possible values are UNIFORM and
    #: SPECTRUM. The default value is SPECTRUM.
    vectorColorMethod: SymbolicConstant = SPECTRUM

    #: A SymbolicConstant specifying the tensor color method. Possible values are UNIFORM and
    #: SPECTRUM. The default value is SPECTRUM.
    tensorColorMethod: SymbolicConstant = SPECTRUM

    #: A SymbolicConstant specifying the vector arrowhead style. Possible values are NONE,
    #: FILLED, and WIRE. The default value is WIRE.
    vectorArrowheadStyle: SymbolicConstant = WIRE

    #: An Int specifying the length of vector and tensor symbols. The default value is 6.
    arrowSymbolSize: int = 6

    #: An Int specifying the number of color intervals for vector symbols. The default value is
    #: 12.
    vectorIntervalNumber: int = 12

    #: A Float specifying the factor for randomized sampling. The default value is 1.0.
    symbolDensity: float = 1

    #: A Boolean specifying whether to use constant-length arrows for vector symbols. The
    #: default value is OFF.
    constantLengthArrows: Boolean = OFF

    #: An Int specifying the number of color intervals for tensor symbols. The default value is
    #: 12.
    tensorIntervalNumber: int = 12

    #: A SymbolicConstant specifying the line thickness of the tensor symbols. Possible values
    #: are VERY_THIN, THIN, MEDIUM, and THICK. The default value is VERY_THIN.
    tensorLineThickness: SymbolicConstant = VERY_THIN

    #: A SymbolicConstant specifying the arrowhead style of the tensor symbols. Possible values
    #: are NONE, FILLED, and WIRE. The default value is WIRE.
    tensorArrowheadStyle: SymbolicConstant = WIRE

    #: A SymbolicConstant specifying the number format for tensor. Possible values are
    #: SCIENTIFIC, FIXED, and ENGINEERING. The default value is SCIENTIFIC.
    numberFormatT: SymbolicConstant = SCIENTIFIC

    #: A SymbolicConstant specifying the number format for vector. Possible values are
    #: SCIENTIFIC, FIXED, and ENGINEERING. The default value is SCIENTIFIC.
    numberFormatV: SymbolicConstant = SCIENTIFIC

    #: A SymbolicConstant specifying the arrow scaling mode. Possible values are MODEL_SIZE and
    #: SCREEN_SIZE. The default value is MODEL_SIZE.
    arrowScaleMode: SymbolicConstant = MODEL_SIZE

    #: A Boolean specifying whether to draw tensor labels. The default value is OFF.
    drawLabelT: Boolean = OFF

    #: A Boolean specifying whether to draw vector labels. The default value is OFF.
    drawLabelV: Boolean = OFF

    #: An Int specifying the number of digits in the tensor label. The default value is 2.
    numDigitsT: int = 2

    #: An Int specifying the number of digits in the vector label. The default value is 2.
    numDigitsV: int = 2

    #: A String specifying the vector color. The default value is "Red".
    vectorColor: str = ""

    #: A String specifying the vector color spectrum name. The default value is "Rainbow".
    vectorColorSpectrum: str = ""

    #: A String specifying the tensor color spectrum name. The default value is "Rainbow".
    tensorColorSpectrum: str = ""

    #: A String specifying the text color for tensor. The default value is "Yellow".
    textColorT: str = ""

    #: A String specifying the text color for vector. The default value is "Yellow".
    textColorV: str = ""

    #: A String specifying the text font for tensor. The default value is "verdana".
    textFontT: str = ""

    #: A String specifying the text font for vector. The default value is "verdana".
    textFontV: str = ""

    #: A String specifying the color of the maximum principal tensor symbols. The default value
    #: is "Red".
    tensorMaxPrinColor: str = ""

    #: A String specifying the color of the minimum principal tensor symbols. The default value
    #: is "Cyan".
    tensorMinPrinColor: str = ""

    #: A String specifying the color of the intermediate principal tensor symbols. The default
    #: value is "Yellow".
    tensorMidPrinColor: str = ""

    #: A String specifying the color of the selected principal tensor symbols. The default
    #: value is "Red".
    tensorSelectedPrinColor: str = ""



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .LayerPropertiesArray import LayerPropertiesArray
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class RebarLayers:
    """The RebarLayers object defines the rebar properties of a section.

    .. note:: 
        This object can be accessed by::

            import section
            mdb.models[name].parts[name].compositeLayups[i].section.rebarLayers
            mdb.models[name].sections[name].rebarLayers
            import odbSection
            session.odbs[name].sections[name].rebarLayers

        The corresponding analysis keywords are:

        - REBAR LAYER
    """

    #: A SymbolicConstant specifying the type of rebar geometry. Possible values are CONSTANT,
    #: ANGULAR, and LIFT_EQUATION.
    rebarSpacing: SymbolicConstant

    #: A :py:class:`~abaqus.Section.LayerPropertiesArray.LayerPropertiesArray` object specifying the layers of reinforcement.
    layerTable: LayerPropertiesArray

    @abaqus_method_doc
    def __init__(
        self, rebarSpacing: SymbolicConstant, layerTable: LayerPropertiesArray
    ):
        """This method creates a RebarLayers object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].parts[name].compositeLayups[i].section.RebarLayers
                mdb.models[name].sections[name].RebarLayers
                session.odbs[name].sections[name].RebarLayers

        Parameters
        ----------
        rebarSpacing
            A SymbolicConstant specifying the type of rebar geometry. Possible values are CONSTANT,
            ANGULAR, and LIFT_EQUATION.
        layerTable
            A :py:class:`~abaqus.Section.LayerPropertiesArray.LayerPropertiesArray` object specifying the layers of reinforcement.

        Returns
        -------
        RebarLayers
            A :py:class:`~abaqus.Section.RebarLayers.RebarLayers` object.
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the RebarLayers object."""
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from ....UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class AcousticMedium:
    """The AcousticMedium object specifies the acoustic properties of a material.

    .. note:: 
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].acousticMedium
            import odbMaterial
            session.odbs[name].materials[name].acousticMedium

        The corresponding analysis keywords are:

        - ACOUSTIC MEDIUM
    """

    @abaqus_method_doc
    def __init__(
        self,
        acousticVolumetricDrag: Boolean = OFF,
        temperatureDependencyB: Boolean = OFF,
        temperatureDependencyV: Boolean = OFF,
        dependenciesB: int = 0,
        dependenciesV: int = 0,
        bulkTable: tuple = (),
        volumetricTable: tuple = (),
    ):
        """This method creates an AcousticMedium object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].materials[name].AcousticMedium
                session.odbs[name].materials[name].AcousticMedium

        Parameters
        ----------
        acousticVolumetricDrag
            A Boolean specifying whether the volumetricTable data is specified. The default value is
            OFF.
        temperatureDependencyB
            A Boolean specifying whether the data in **bulkTable** depend on temperature. The default
            value is OFF.
        temperatureDependencyV
            A Boolean specifying whether the data in **volumetricTable** depend on temperature. The
            default value is OFF.
        dependenciesB
            An Int specifying the number of field variable dependencies for the data in **bulkTable**.
            The default value is 0.
        dependenciesV
            An Int specifying the number of field variable dependencies for the data in
            **volumetricTable**. The default value is 0.
        bulkTable
            A sequence of sequences of Floats specifying the following:
            
            - Bulk modulus.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
        volumetricTable
            A sequence of sequences of Floats specifying the following:
            
            - Volumetric drag.
            - Frequency.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
            
            The default value is an empty sequence.

        Returns
        -------
        AcousticMedium
            An :py:class:`~abaqus.Material.Others.Acoustic.AcousticMedium.AcousticMedium` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the AcousticMedium object.

        Raises
        ------
        RangeError
        """
        ...



import abqpy.abaqus
from .Canvas.Highlight import *
from .Mdb.Mdb import Mdb as AbaqusMdb
from .Odb.Odb import Odb
from .Session.Session import Session as AbaqusSession
from .UtilityAndView.BackwardCompatibility import BackwardCompatibility
from .UtilityAndView.SymbolicConstant import SymbolicConstant
from .UtilityAndView.abaqusConstants import Boolean, OFF
from .UtilityAndView.User import *


class Mdb(AbaqusMdb):

    def __init__(self, pathName: str = ""):
        super().__init__(pathName)

    def save(self):
        super().save()

    def saveAs(self, pathName: str):
        abqpy.abaqus.run()


class Session(AbaqusSession):

    def openOdb(self, name: str, path: str = "", readOnly: Boolean = OFF) -> Odb:
        """This method opens an existing output database (`.odb`) file and creates a new Odb object.
        This method is accessed only via the session object inside Abaqus/CAE and adds the new
        Odb object to the session.odbs repository. This method allows you to open multiple
        output databases at the same time and to use the repository key to specify a particular
        output database. For example::
        
            import visualization
            session.openOdb(name='myOdb', path='stress.odb', readOnly=True)

        Parameters
        ----------
        name
            A String specifying the repository key. If the `name` is not the same as the `path` to the
            output database (`.odb`) file, the `path` must be specified as well. Additionally, to
            support backwards compatibility of the interface, if the `name` parameter is omitted,
            the `path` and `name` will be presumed to be the same.
        path
            A String specifying the path to an existing output database (`.odb`) file.
        readOnly
            A Boolean specifying whether the file will permit only read access or both read and
            write access. The initial value is TRUE when the output database file is opened from
            Abaqus/CAE, indicating that only read access will be permitted.

        Returns
        -------
        Odb
            An :py:class:`~abaqus.Odb.Odb.Odb` object.

        Raises
        ------
        OdbError: The database is from a previous release of Abaqus
            If the output database was generated by a previous release of Abaqus and needs
            upgrading, Run  `abaqus upgrade -job <newFilename> -odb <oldFileName>` to upgrade it.
        OdbError: Abaqus installation must be upgraded before this output database can be opened
            If the output database was generated by a newer release of Abaqus, and the
            installation of Abaqus needs upgrading.
        AbaqusError: Cannot open file <filename>
            If the file is not a valid database.
        """
        self.odbs[name] = odb = Odb(name)
        abqpy.abaqus.run()
        return odb


session = Session()
mdb = Mdb()

backwardCompatibility = BackwardCompatibility()

YES = SymbolicConstant('YES')
NO = SymbolicConstant('NO')



from abqpy.decorators import abaqus_class_doc
from ..EditMesh.MeshEditPart import MeshEditPart
from ..Mesh.MeshPart import MeshPart
from ..Property.PropertyPart import PropertyPart
from ..Region.RegionPart import RegionPart


@abaqus_class_doc
class Part(MeshEditPart, MeshPart, PropertyPart, RegionPart):
    """The Part object defines the physical attributes of a structure. Parts are instanced into
    the assembly and positioned before an analysis.

    .. note:: 
        This object can be accessed by::

            import part
            mdb.models[name].parts[name]
    """
    ...



from abqpy.decorators import abaqus_class_doc
from .InteractionState import InteractionState
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class RadiationToAmbientState(InteractionState):
    """The RadiationToAmbientState object stores the propagating data for a RadiationToAmbient
    object. One instance of this object is created internally by the RadiationToAmbient
    object for each step. The instance is also deleted internally by the RadiationToAmbient
    object.
    The RadiationToAmbientState object has no constructor or methods.
    The RadiationToAmbientState object is derived from the InteractionState object.

    .. note:: 
        This object can be accessed by::

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

        The corresponding analysis keywords are:

        - SRADIATE
    """

    #: A Float specifying the ambient temperature.
    ambientTemperature: float = None

    #: A SymbolicConstant specifying the propagation state of the **ambientTemperature** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    ambientTemperatureState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the **ambientTemperatureAmp**
    #: member. Possible values are UNSET, SET, UNCHANGED, and FREED.
    ambientTemperatureAmpState: SymbolicConstant = None

    #: A Float specifying the emissivity.
    emissivity: float = None

    #: A SymbolicConstant specifying the propagation state of the **emissivity** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    emissivityState: SymbolicConstant = None

    #: A String specifying the name of the Amplitude object that gives the variation of the
    #: ambient temperature with time.
    ambientTemperatureAmp: str = ""

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None



import typing

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .Density.Density import Density
from .Elastic.HyperElastic.HyperFoam.Hyperfoam import Hyperfoam
from .Elastic.HyperElastic.Hyperelastic import Hyperelastic
from .Elastic.HyperElastic.ViscoElastic.Viscoelastic import Viscoelastic
from .Elastic.HypoElastic.Hypoelastic import Hypoelastic
from .Elastic.Linear.Elastic import Elastic
from .Elastic.LowDensityFoam.LowDensityFoam import LowDensityFoam
from .Elastic.Porous.PorousElastic import PorousElastic
from .Eos.Eos import Eos
from .Gap.GapFlow import GapFlow
from .Gasket.GasketMembraneElastic import GasketMembraneElastic
from .Gasket.GasketThicknessBehavior import GasketThicknessBehavior
from .Gasket.GasketTransverseShearElastic import GasketTransverseShearElastic
from .Others.Acoustic.AcousticMedium import AcousticMedium
from .Others.Electromagnetic.Dielectric import Dielectric
from .Others.Electromagnetic.ElectricalConductivity import ElectricalConductivity
from .Others.Electromagnetic.MagneticPermeability import MagneticPermeability
from .Others.Electromagnetic.Piezoelectric import Piezoelectric
from .Others.HeatTransfer.Conductivity import Conductivity
from .Others.HeatTransfer.HeatGeneration import HeatGeneration
from .Others.HeatTransfer.InelasticHeatFraction import InelasticHeatFraction
from .Others.HeatTransfer.JouleHeatFraction import JouleHeatFraction
from .Others.HeatTransfer.LatentHeat import LatentHeat
from .Others.HeatTransfer.SpecificHeat import SpecificHeat
from .Others.MassDiffusion.Diffusivity import Diffusivity
from .Others.MassDiffusion.Solubility import Solubility
from .Others.Mechanical.Damping import Damping
from .Others.Mechanical.Expansion import Expansion
from .Others.Mechanical.PoreFluidExpansion import PoreFluidExpansion
from .Others.Mechanical.Viscosity.Viscosity import Viscosity
from .Others.PoreFluidFlow.FluidLeakoff import FluidLeakoff
from .Others.PoreFluidFlow.Gel import Gel
from .Others.PoreFluidFlow.MoistureSwelling.MoistureSwelling import MoistureSwelling
from .Others.PoreFluidFlow.Permeability.Permeability import Permeability
from .Others.PoreFluidFlow.PorousBulkModuli import PorousBulkModuli
from .Others.PoreFluidFlow.Sorption import Sorption
from .Others.User.Depvar import Depvar
from .Others.User.UserDefinedField import UserDefinedField
from .Others.User.UserMaterial import UserMaterial
from .Others.User.UserOutputVariables import UserOutputVariables
from .Plastic.Concrete.BrittleCracking import BrittleCracking
from .Plastic.Concrete.Concrete import Concrete
from .Plastic.Concrete.ConcreteDamagedPlasticity import ConcreteDamagedPlasticity
from .Plastic.Creep.Creep import Creep
from .Plastic.CriticalStateClay.ClayPlasticity import ClayPlasticity
from .Plastic.CrushableFoam.CrushableFoam import CrushableFoam
from .Plastic.DruckerPrager.Extended.DruckerPrager import DruckerPrager
from .Plastic.DruckerPrager.ModifiedCap.CapPlasticity import CapPlasticity
from .Plastic.Metal.CastIron.CastIronPlasticity import CastIronPlasticity
from .Plastic.Metal.Deformation.DeformationPlasticity import DeformationPlasticity
from .Plastic.Metal.Porous.PorousMetalPlasticity import PorousMetalPlasticity
from .Plastic.Metal.TwoLayerViscoPlasticity.Viscous import Viscous
from .Plastic.MohrCoulomb.MohrCoulombPlasticity import MohrCoulombPlasticity
from .Plastic.Plastic import Plastic
from .Plastic.Swelling.Swelling import Swelling
from .ProgressiveDamageFailure.DamageInitiation import DamageInitiation
from .Regularization import Regularization
from .TestData.MullinsEffect import MullinsEffect
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class MaterialBase:
    """A :py:class:`~abaqus.Material.Material.Material` object is the object used to specify a material. The Material object stores
    the various settings that determine how a material behaves.
    A material is created by combining one or more individual material options and sub
    options. A particular material option is associated with the Material object through a
    member. For example: the **acousticMedium** member may contain an AcousticMedium object.
    The alternative of having a MaterialOption abstract base class and a container of
    MaterialOptions was rejected because it would make it more difficult to enforce the fact
    that one Material object cannot contain two AcousticMedium objects, for example.

    .. note:: 
        This object can be accessed by::

            import material
            mdb.models[name].materials[name]
            import odbMaterial
            session.odbs[name].materials[name]

        The corresponding analysis keywords are:

        - MATERIAL
    """

    #: An :py:class:`~abaqus.Material.Others.Acoustic.AcousticMedium.AcousticMedium` object.
    acousticMedium: AcousticMedium = AcousticMedium()

    #: A :py:class:`~abaqus.Material.Plastic.Concrete.BrittleCracking.BrittleCracking` object.
    brittleCracking: BrittleCracking = BrittleCracking(((),))

    #: A :py:class:`~abaqus.Material.Plastic.DruckerPrager.ModifiedCap.CapPlasticity.CapPlasticity` object.
    capPlasticity: CapPlasticity = CapPlasticity(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Metal.CastIron.CastIronPlasticity.CastIronPlasticity` object.
    castIronPlasticity: CastIronPlasticity = CastIronPlasticity(((),))

    #: A :py:class:`~abaqus.Material.Plastic.CriticalStateClay.ClayPlasticity.ClayPlasticity` object.
    clayPlasticity: ClayPlasticity = ClayPlasticity(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Concrete.Concrete.Concrete` object.
    concrete: Concrete = Concrete(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Concrete.ConcreteDamagedPlasticity.ConcreteDamagedPlasticity` object.
    concreteDamagedPlasticity: ConcreteDamagedPlasticity = ConcreteDamagedPlasticity(
        ((),)
    )

    #: A :py:class:`~abaqus.Material.Others.HeatTransfer.Conductivity.Conductivity` object.
    conductivity: Conductivity = Conductivity(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Creep.Creep.Creep` object.
    creep: Creep = Creep(((),))

    #: A :py:class:`~abaqus.Material.Plastic.CrushableFoam.CrushableFoam.CrushableFoam` object.
    crushableFoam: CrushableFoam = CrushableFoam(((),))

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    ductileDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    fldDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    flsdDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    johnsonCookDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    maxeDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    maxsDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    maxpeDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    maxpsDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    mkDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    msfldDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    quadeDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    quadsDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    shearDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageInitiation.DamageInitiation` object.
    hashinDamageInitiation: DamageInitiation = DamageInitiation()

    #: A :py:class:`~abaqus.Material.Others.Mechanical.Damping.Damping` object.
    damping: Damping = Damping()

    #: A :py:class:`~abaqus.Material.Plastic.Metal.Deformation.DeformationPlasticity.DeformationPlasticity` object.
    deformationPlasticity: DeformationPlasticity = DeformationPlasticity(((),))

    #: A :py:class:`~abaqus.Material.Density.Density.Density` object.
    density: Density = Density(((),))

    #: A :py:class:`~abaqus.Material.Others.User.Depvar.Depvar` object.
    depvar: Depvar = Depvar()

    #: A :py:class:`~abaqus.Material.Others.Electromagnetic.Dielectric.Dielectric` object.
    dielectric: Dielectric = Dielectric(((),))

    #: A :py:class:`~abaqus.Material.Others.MassDiffusion.Diffusivity.Diffusivity` object.
    diffusivity: Diffusivity = Diffusivity(((),))

    #: A :py:class:`~abaqus.Material.Plastic.DruckerPrager.Extended.DruckerPrager.DruckerPrager` object.
    druckerPrager: DruckerPrager = DruckerPrager(((),))

    #: An :py:class:`~abaqus.Material.Elastic.Linear.Elastic.Elastic` object.
    elastic: Elastic = Elastic(((),))

    #: An :py:class:`~abaqus.Material.Others.Electromagnetic.ElectricalConductivity.ElectricalConductivity` object.
    electricalConductivity: ElectricalConductivity = ElectricalConductivity(((),))

    #: An :py:class:`~abaqus.Material.Eos.Eos.Eos` object.
    eos: Eos = Eos()

    #: An :py:class:`~abaqus.Material.Others.Mechanical.Expansion.Expansion` object.
    expansion: Expansion = Expansion()

    #: A :py:class:`~abaqus.Material.Others.PoreFluidFlow.FluidLeakoff.FluidLeakoff` object.
    fluidLeakoff: FluidLeakoff = FluidLeakoff()

    #: A :py:class:`~abaqus.Material.Gap.GapFlow.GapFlow` object.
    gapFlow: GapFlow = GapFlow(((),))

    #: A :py:class:`~abaqus.Material.Gasket.GasketThicknessBehavior.GasketThicknessBehavior` object.
    gasketThicknessBehavior: GasketThicknessBehavior = GasketThicknessBehavior(((),))

    #: A :py:class:`~abaqus.Material.Gasket.GasketTransverseShearElastic.GasketTransverseShearElastic` object.
    gasketTransverseShearElastic: GasketTransverseShearElastic = (
        GasketTransverseShearElastic(((),))
    )

    #: A :py:class:`~abaqus.Material.Gasket.GasketMembraneElastic.GasketMembraneElastic` object.
    gasketMembraneElastic: GasketMembraneElastic = GasketMembraneElastic(((),))

    #: A :py:class:`~abaqus.Material.Others.PoreFluidFlow.Gel.Gel` object.
    gel: Gel = Gel(((),))

    #: A :py:class:`~abaqus.Material.Others.HeatTransfer.HeatGeneration.HeatGeneration` object.
    heatGeneration: HeatGeneration = HeatGeneration()

    #: A :py:class:`~abaqus.Material.Elastic.HyperElastic.Hyperelastic.Hyperelastic` object.
    hyperelastic: Hyperelastic = Hyperelastic(((),))

    #: A :py:class:`~abaqus.Material.Elastic.HyperElastic.HyperFoam.Hyperfoam.Hyperfoam` object.
    hyperfoam: Hyperfoam = Hyperfoam()

    #: A :py:class:`~abaqus.Material.Elastic.HypoElastic.Hypoelastic.Hypoelastic` object.
    hypoelastic: Hypoelastic = Hypoelastic(((),))

    #: An :py:class:`~abaqus.Material.Others.HeatTransfer.InelasticHeatFraction.InelasticHeatFraction` object.
    inelasticHeatFraction: InelasticHeatFraction = InelasticHeatFraction()

    #: A :py:class:`~abaqus.Material.Others.HeatTransfer.JouleHeatFraction.JouleHeatFraction` object.
    jouleHeatFraction: JouleHeatFraction = JouleHeatFraction()

    #: A :py:class:`~abaqus.Material.Others.HeatTransfer.LatentHeat.LatentHeat` object.
    latentHeat: LatentHeat = LatentHeat(((),))

    #: A :py:class:`~abaqus.Material.Elastic.LowDensityFoam.LowDensityFoam.LowDensityFoam` object.
    lowDensityFoam: LowDensityFoam = LowDensityFoam()

    #: A :py:class:`~abaqus.Material.Others.Electromagnetic.MagneticPermeability.MagneticPermeability` object.
    magneticPermeability: MagneticPermeability = MagneticPermeability(
        ((),), ((),), ((),)
    )

    #: A :py:class:`~abaqus.Material.Plastic.MohrCoulomb.MohrCoulombPlasticity.MohrCoulombPlasticity` object.
    mohrCoulombPlasticity: MohrCoulombPlasticity = MohrCoulombPlasticity(((),))

    #: A :py:class:`~abaqus.Material.Others.PoreFluidFlow.MoistureSwelling.MoistureSwelling.MoistureSwelling` object.
    moistureSwelling: MoistureSwelling = MoistureSwelling(((),))

    #: A :py:class:`~abaqus.Material.TestData.MullinsEffect.MullinsEffect` object.
    mullinsEffect: MullinsEffect = MullinsEffect()

    #: A :py:class:`~abaqus.Material.Others.PoreFluidFlow.Permeability.Permeability.Permeability` object.
    permeability: Permeability = Permeability(0, 0, ((),))

    #: A :py:class:`~abaqus.Material.Others.Electromagnetic.Piezoelectric.Piezoelectric` object.
    piezoelectric: Piezoelectric = Piezoelectric(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Plastic.Plastic` object.
    plastic: Plastic = Plastic(((),))

    #: A :py:class:`~abaqus.Material.Others.Mechanical.PoreFluidExpansion.PoreFluidExpansion` object.
    poreFluidExpansion: PoreFluidExpansion = PoreFluidExpansion(((),))

    #: A :py:class:`~abaqus.Material.Others.PoreFluidFlow.PorousBulkModuli.PorousBulkModuli` object.
    porousBulkModuli: PorousBulkModuli = PorousBulkModuli(((),))

    #: A :py:class:`~abaqus.Material.Elastic.Porous.PorousElastic.PorousElastic` object.
    porousElastic: PorousElastic = PorousElastic(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Metal.Porous.PorousMetalPlasticity.PorousMetalPlasticity` object.
    porousMetalPlasticity: PorousMetalPlasticity = PorousMetalPlasticity(((),))

    #: A :py:class:`~abaqus.Material.Regularization.Regularization` object.
    regularization: Regularization = Regularization()

    #: A :py:class:`~abaqus.Material.Others.MassDiffusion.Solubility.Solubility` object.
    solubility: Solubility = Solubility(((),))

    #: A :py:class:`~abaqus.Material.Others.PoreFluidFlow.Sorption.Sorption` object.
    sorption: Sorption = Sorption(((),))

    #: A :py:class:`~abaqus.Material.Others.HeatTransfer.SpecificHeat.SpecificHeat` object.
    specificHeat: SpecificHeat = SpecificHeat(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Swelling.Swelling.Swelling` object.
    swelling: Swelling = Swelling(((),))

    #: A :py:class:`~abaqus.Material.Others.User.UserDefinedField.UserDefinedField` object.
    userDefinedField: UserDefinedField = UserDefinedField()

    #: A :py:class:`~abaqus.Material.Others.User.UserMaterial.UserMaterial` object.
    userMaterial: UserMaterial = UserMaterial()

    #: A :py:class:`~abaqus.Material.Others.User.UserOutputVariables.UserOutputVariables` object.
    userOutputVariables: UserOutputVariables = UserOutputVariables()

    #: A :py:class:`~abaqus.Material.Elastic.HyperElastic.ViscoElastic.Viscoelastic.Viscoelastic` object.
    viscoelastic: Viscoelastic = Viscoelastic(FREQUENCY, ((),))

    #: A :py:class:`~abaqus.Material.Others.Mechanical.Viscosity.Viscosity.Viscosity` object.
    viscosity: Viscosity = Viscosity(((),))

    #: A :py:class:`~abaqus.Material.Plastic.Metal.TwoLayerViscoPlasticity.Viscous.Viscous` object.
    viscous: Viscous = Viscous(((),))

    @abaqus_method_doc
    def __init__(self, name: str, description: str = "", materialIdentifier: str = ""):
        """This method creates a Material object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].Material
                session.odbs[name].Material

        Parameters
        ----------
        name
            A String specifying the name of the new material.
        description
            A String specifying user description of the material. The default value is an empty
            string.
        materialIdentifier
            A String specifying material identifier for customer use. The default value is an empty
            string.

        Returns
        -------
        Material
            A :py:class:`~abaqus.Material.Material.Material` object.
        """
        self.name, self.description, self.materialIdentifier = (
            name,
            description,
            materialIdentifier,
        )

    @abaqus_method_doc
    def materialsFromOdb(self, fileName: str):
        """This methods creates Material objects by reading an output database. The new materials
        are placed in the materials repository.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].Material
                session.odbs[name].Material

        Parameters
        ----------
        fileName
            A String specifying the name of the output database file (including the .odb extension)
            to be read. This String can also be the full path to the output database file if it is
            located in another directory.

        Returns
        -------
        typing.List[Material]
            A list of :py:class:`~abaqus.Material.Material.Material` objects.
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .Interaction import Interaction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class StdXplCosimulation(Interaction):
    """The StdXplCosimulation object defines co-simulation behavior between Abaqus/Standard and
    Abaqus/Explicit.
    The StdXplCosimulation object is derived from the Interaction object.

    .. note:: 
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name]
    """

    #: A String specifying the repository key.
    name: str

    #: A String specifying the name of the step in which the StdXplCosimulation object is
    #: created.
    createStepName: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the import and export region upon which the co-simulation
    #: exchanges data with the coupled analysis program.
    region: Region

    #: A SymbolicConstant specifying whether the analysis programs use the same time increments
    #: or one is allowed to use more time increments than the other before exchanging data.
    #: Possible values are ALLOW_SUBCYCLING and LOCKSTEP. The default value is
    #: ALLOW_SUBCYCLING.
    incrementation: SymbolicConstant = ALLOW_SUBCYCLING

    #: A Float specifying the size of the increments to be used by Abaqus/Standard and
    #: Abaqus/Explicit. The default value is 0.0.
    stepSize: float = 0

    #: A SymbolicConstant specifying whether the increment size is the analysis default or a
    #: supplied variable. Possible values are DEFAULT and SPECIFIED. The default value is
    #: DEFAULT.
    stepSizeDefinition: SymbolicConstant = DEFAULT

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        incrementation: SymbolicConstant = ALLOW_SUBCYCLING,
        stepSize: float = 0,
        stepSizeDefinition: SymbolicConstant = DEFAULT,
    ):
        """This method creates a StdXplCosimulation object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].StdXplCosimulation

        Parameters
        ----------
        name
            A String specifying the repository key.
        createStepName
            A String specifying the name of the step in which the StdXplCosimulation object is
            created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the import and export region upon which the co-simulation
            exchanges data with the coupled analysis program.
        incrementation
            A SymbolicConstant specifying whether the analysis programs use the same time increments
            or one is allowed to use more time increments than the other before exchanging data.
            Possible values are ALLOW_SUBCYCLING and LOCKSTEP. The default value is
            ALLOW_SUBCYCLING.
        stepSize
            A Float specifying the size of the increments to be used by Abaqus/Standard and
            Abaqus/Explicit. The default value is 0.0.
        stepSizeDefinition
            A SymbolicConstant specifying whether the increment size is the analysis default or a
            supplied variable. Possible values are DEFAULT and SPECIFIED. The default value is
            DEFAULT.

        Returns
        -------
        StdXplCosimulation
            A :py:class:`~abaqus.Interaction.StdXplCosimulation.StdXplCosimulation` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        incrementation: SymbolicConstant = ALLOW_SUBCYCLING,
        stepSize: float = 0,
        stepSizeDefinition: SymbolicConstant = DEFAULT,
    ):
        """This method modifies the StdXplCosimulation object.

        Parameters
        ----------
        incrementation
            A SymbolicConstant specifying whether the analysis programs use the same time increments
            or one is allowed to use more time increments than the other before exchanging data.
            Possible values are ALLOW_SUBCYCLING and LOCKSTEP. The default value is
            ALLOW_SUBCYCLING.
        stepSize
            A Float specifying the size of the increments to be used by Abaqus/Standard and
            Abaqus/Explicit. The default value is 0.0.
        stepSizeDefinition
            A SymbolicConstant specifying whether the increment size is the analysis default or a
            supplied variable. Possible values are DEFAULT and SPECIFIED. The default value is
            DEFAULT.
        """
        ...



import typing

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .BoundaryCondition import BoundaryCondition
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class DisplacementBC(BoundaryCondition):
    """The DisplacementBC object stores the data for a displacement/rotation boundary
    condition.
    The DisplacementBC object is derived from the BoundaryCondition object.

    .. note:: 
        This object can be accessed by::

            import load
            mdb.models[name].boundaryConditions[name]
    """

    #: A String specifying the boundary condition repository key.
    name: str = ""

    #: A SymbolicConstant specifying how the boundary condition is distributed spatially.
    #: Possible values are UNIFORM, USER_DEFINED, FIELD, and DISCRETE_FIELD. The default value
    #: is UNIFORM.
    distributionType: SymbolicConstant = UNIFORM

    #: A Boolean specifying whether the boundary condition should remain fixed at the current
    #: values at the start of the step. The default value is OFF.
    fixed: Boolean = OFF

    #: A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
    #: analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
    #: PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
    buckleCase: SymbolicConstant = NOT_APPLICABLE

    #: A String specifying the name of the AnalyticalField or DiscreteField object associated
    #: with this boundary condition. The **fieldName** argument applies only when
    #: **distributionType** = FIELD or **distributionType** = DISCRETE_FIELD. The default value is an
    #: empty string.
    fieldName: str = ""

    #: A SymbolicConstant specifying the category of the boundary condition. Possible values
    #: are MECHANICAL and THERMAL.
    category: SymbolicConstant = None

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
    region: Region = Region()

    #: None or a DatumCsys object specifying the local coordinate system of the boundary
    #: condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
    #: in the global coordinate system. The default value is None.
    localCsys: str = None

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        region: Region,
        fieldName: str = "",
        u1: typing.Union[SymbolicConstant, float] = UNSET,
        u2: typing.Union[SymbolicConstant, float] = UNSET,
        u3: typing.Union[SymbolicConstant, float] = UNSET,
        ur1: typing.Union[SymbolicConstant, float] = UNSET,
        ur2: typing.Union[SymbolicConstant, float] = UNSET,
        ur3: typing.Union[SymbolicConstant, float] = UNSET,
        fixed: Boolean = OFF,
        amplitude: str = UNSET,
        distributionType: SymbolicConstant = UNIFORM,
        localCsys: str = None,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
    ):
        """This method creates a DisplacementBC object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].DisplacementBC

        Parameters
        ----------
        name
            A String specifying the boundary condition repository key.
        createStepName
            A String specifying the name of the step in which the boundary condition is created.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the boundary condition is applied.
        fieldName
            A String specifying the name of the AnalyticalField or DiscreteField object associated
            with this boundary condition. The **fieldName** argument applies only when
            **distributionType** = FIELD or **distributionType** = DISCRETE_FIELD. The default value is an
            empty string.
        u1
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            1-direction. Possible values for the SymbolicConstant are UNSET and SET. The default
            value is UNSET.Note:Although **u1**, **u2**, **u3**, **ur1**, **ur2**, and **ur3** are optional
            arguments, at least one of them must be specified.
        u2
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            2-direction. Possible values for the SymbolicConstant are UNSET and SET. The default
            value is UNSET.
        u3
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            3-direction. Possible values for the SymbolicConstant are UNSET and SET. The default
            value is UNSET.
        ur1
            A Float, a Complex, or a SymbolicConstant specifying the rotational displacement
            component about the 1-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        ur2
            A Float, a Complex, or a SymbolicConstant specifying the rotational displacement
            component about the 2-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        ur3
            A Float, a Complex, or a SymbolicConstant specifying the rotational displacement
            component about the 3-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        fixed
            A Boolean specifying whether the boundary condition should remain fixed at the current
            values at the start of the step. The default value is OFF.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the boundary condition has no amplitude reference. The default
            value is UNSET. You should provide the **amplitude** argument only if it is valid for the
            specified step.
        distributionType
            A SymbolicConstant specifying how the boundary condition is distributed spatially.
            Possible values are UNIFORM, USER_DEFINED, FIELD, and DISCRETE_FIELD. The default value
            is UNIFORM.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.

        Returns
        -------
        DisplacementBC
            A :py:class:`~abaqus.BoundaryCondition.DisplacementBC.DisplacementBC` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        fieldName: str = "",
        u1: typing.Union[SymbolicConstant, float] = UNSET,
        u2: typing.Union[SymbolicConstant, float] = UNSET,
        u3: typing.Union[SymbolicConstant, float] = UNSET,
        ur1: typing.Union[SymbolicConstant, float] = UNSET,
        ur2: typing.Union[SymbolicConstant, float] = UNSET,
        ur3: typing.Union[SymbolicConstant, float] = UNSET,
        fixed: Boolean = OFF,
        amplitude: str = UNSET,
        distributionType: SymbolicConstant = UNIFORM,
        localCsys: str = None,
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
    ):
        """This method modifies the data for an existing DisplacementBC object in the step where it
        is created.

        Parameters
        ----------
        fieldName
            A String specifying the name of the AnalyticalField or DiscreteField object associated
            with this boundary condition. The **fieldName** argument applies only when
            **distributionType** = FIELD or **distributionType** = DISCRETE_FIELD. The default value is an
            empty string.
        u1
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            1-direction. Possible values for the SymbolicConstant are UNSET and SET. The default
            value is UNSET.Note:Although **u1**, **u2**, **u3**, **ur1**, **ur2**, and **ur3** are optional
            arguments, at least one of them must be specified.
        u2
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            2-direction. Possible values for the SymbolicConstant are UNSET and SET. The default
            value is UNSET.
        u3
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            3-direction. Possible values for the SymbolicConstant are UNSET and SET. The default
            value is UNSET.
        ur1
            A Float, a Complex, or a SymbolicConstant specifying the rotational displacement
            component about the 1-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        ur2
            A Float, a Complex, or a SymbolicConstant specifying the rotational displacement
            component about the 2-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        ur3
            A Float, a Complex, or a SymbolicConstant specifying the rotational displacement
            component about the 3-direction. Possible values for the SymbolicConstant are UNSET and
            SET. The default value is UNSET.
        fixed
            A Boolean specifying whether the boundary condition should remain fixed at the current
            values at the start of the step. The default value is OFF.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the boundary condition has no amplitude reference. The default
            value is UNSET. You should provide the **amplitude** argument only if it is valid for the
            specified step.
        distributionType
            A SymbolicConstant specifying how the boundary condition is distributed spatially.
            Possible values are UNIFORM, USER_DEFINED, FIELD, and DISCRETE_FIELD. The default value
            is UNIFORM.
        localCsys
            None or a DatumCsys object specifying the local coordinate system of the boundary
            condition's degrees of freedom. If **localCsys** = None, the degrees of freedom are defined
            in the global coordinate system. The default value is None.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        u1: typing.Union[SymbolicConstant, float] = SET,
        u2: typing.Union[SymbolicConstant, float] = SET,
        u3: typing.Union[SymbolicConstant, float] = SET,
        ur1: typing.Union[SymbolicConstant, float] = SET,
        ur2: typing.Union[SymbolicConstant, float] = SET,
        ur3: typing.Union[SymbolicConstant, float] = SET,
        amplitude: str = "",
        buckleCase: SymbolicConstant = NOT_APPLICABLE,
    ):
        """This method modifies the propagating data for an existing DisplacementBC object in the
        specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the boundary condition is modified.
        u1
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            1-direction. Possible values for the SymbolicConstant are SET, UNCHANGED, and FREED.
        u2
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            2-direction. Possible values for the SymbolicConstant are SET, UNCHANGED, and FREED.
        u3
            A Float, a Complex, or a SymbolicConstant specifying the displacement component in the
            3-direction. Possible values for the SymbolicConstant are SET, UNCHANGED, and FREED.
        ur1
            A Float, a Complex, or a SymbolicConstant specifying the rotational displacement
            component about the 1-direction. Possible values for the SymbolicConstant are SET,
            UNCHANGED, and FREED.
        ur2
            A Float, a Complex, or a SymbolicConstant specifying the rotational displacement
            component about the 2-direction. Possible values for the SymbolicConstant are SET,
            UNCHANGED, and FREED.
        ur3
            A Float, a Complex, or a SymbolicConstant specifying the rotational displacement
            component about the 3-direction. Possible values for the SymbolicConstant are SET,
            UNCHANGED, and FREED.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous analysis step. FREED should be used if the
            boundary condition is changed to have no amplitude reference. You should provide the
            **amplitude** argument only if it is valid for the specified step.
        buckleCase
            A SymbolicConstant specifying how the boundary condition is defined in a BUCKLE
            analysis. Possible values are NOT_APPLICABLE, STRESS_PERTURBATION, BUCKLING_MODES, and
            PERTURBATION_AND_BUCKLING. The default value is NOT_APPLICABLE.
        """
        ...



import typing

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .MeshElement import MeshElement


@abaqus_class_doc
class MeshElementArray(typing.List[MeshElement]):
    """The MeshElementArray is a sequence of MeshElement objects.

    .. note:: 
        This object can be accessed by::

            import part
            mdb.models[name].parts[name].allInternalSets[name].elements
            mdb.models[name].parts[name].allInternalSurfaces[name].elements
            mdb.models[name].parts[name].allSets[name].elements
            mdb.models[name].parts[name].allSurfaces[name].elements
            mdb.models[name].parts[name].elements
            mdb.models[name].parts[name].sets[name].elements
            mdb.models[name].parts[name].surfaces[name].elements
            import assembly
            mdb.models[name].rootAssembly.allInstances[name].elements
            mdb.models[name].rootAssembly.allInstances[name].sets[name].elements
            mdb.models[name].rootAssembly.allInstances[name].surfaces[name].elements
            mdb.models[name].rootAssembly.allInternalSets[name].elements
            mdb.models[name].rootAssembly.allInternalSurfaces[name].elements
            mdb.models[name].rootAssembly.allSets[name].elements
            mdb.models[name].rootAssembly.allSurfaces[name].elements
            mdb.models[name].rootAssembly.elements
            mdb.models[name].rootAssembly.instances[name].elements
            mdb.models[name].rootAssembly.instances[name].sets[name].elements
            mdb.models[name].rootAssembly.instances[name].surfaces[name].elements
            mdb.models[name].rootAssembly.modelInstances[i].elements
            mdb.models[name].rootAssembly.modelInstances[i].sets[name].elements
            mdb.models[name].rootAssembly.modelInstances[i].surfaces[name].elements
            mdb.models[name].rootAssembly.sets[name].elements
            mdb.models[name].rootAssembly.surfaces[name].elements
    """

    @abaqus_method_doc
    def __init__(self, elements: typing.List[MeshElement]):
        """This method creates a MeshElementArray object.

        .. note:: 
            This function can be accessed by::

                mesh.MeshElementArray

        Parameters
        ----------
        elements
            A list of MeshElement objects.

        Returns
        -------
        MeshElementArray
            A :py:class:`~abaqus.Mesh.MeshElementArray.MeshElementArray` object.
        """
        super().__init__()

    @abaqus_method_doc
    def getFromLabel(self, label: int):
        """This method returns the object in the MeshElementArray with the given label.

        Parameters
        ----------
        label
            An Int specifying the label of the object.

        Returns
        -------
        MeshElement
            A :py:class:`~abaqus.Mesh.MeshElement.MeshElement` object.
        """
        ...

    @abaqus_method_doc
    def getSequenceFromMask(self, mask: str):
        """This method returns the objects in the MeshElementArray identified using the specified
        **mask**. This command is generated when the JournalOptions are set to COMPRESSEDINDEX.
        When a large number of objects are involved, this method is highly efficient.

        Parameters
        ----------
        mask
            A String specifying the object or objects.

        Returns
        -------
        MeshElementArray
            A :py:class:`~abaqus.Mesh.MeshElementArray.MeshElementArray` object.
        """
        ...

    @abaqus_method_doc
    def getMask(self):
        """This method returns a string specifying the object or objects.

        Returns
        -------
        str
            A String specifying the object or objects.
        """
        ...

    @abaqus_method_doc
    def getByBoundingBox(
        self,
        xMin: str = "",
        yMin: str = "",
        zMin: str = "",
        xMax: str = "",
        yMax: str = "",
        zMax: str = "",
    ):
        """This method returns an array of element objects that lie within the specified bounding
        box.

        Parameters
        ----------
        xMin
            A float specifying the minimum X boundary of the bounding box.
        yMin
            A float specifying the minimum Y boundary of the bounding box.
        zMin
            A float specifying the minimum Z boundary of the bounding box.
        xMax
            A float specifying the maximum X boundary of the bounding box.
        yMax
            A float specifying the maximum Y boundary of the bounding box.
        zMax
            A float specifying the maximum Z boundary of the bounding box.

        Returns
        -------
        MeshElementArray
            A :py:class:`~abaqus.Mesh.MeshElementArray.MeshElementArray` object, which is a sequence of MeshElement objects.
        """
        ...

    @abaqus_method_doc
    def getByBoundingCylinder(self, center1: tuple, center2: tuple, radius: str):
        """This method returns an array of element objects that lie within the specified bounding
        cylinder.

        Parameters
        ----------
        center1
            A tuple of the X-, Y-, and Z-coordinates of the center of the first end of the cylinder.
        center2
            A tuple of the X-, Y-, and Z-coordinates of the center of the second end of the
            cylinder.
        radius
            A float specifying the radius of the cylinder.

        Returns
        -------
        MeshElementArray
            A :py:class:`~abaqus.Mesh.MeshElementArray.MeshElementArray` object, which is a sequence of MeshElement objects.
        """
        ...

    @abaqus_method_doc
    def getByBoundingSphere(self, center: tuple, radius: str):
        """This method returns an array of element objects that lie within the specified bounding
        sphere.

        Parameters
        ----------
        center
            A tuple of the X-, Y-, and Z-coordinates of the center of the sphere.
        radius
            A float specifying the radius of the sphere.

        Returns
        -------
        MeshElementArray
            A :py:class:`~abaqus.Mesh.MeshElementArray.MeshElementArray` object, which is a sequence of MeshElement objects.
        """
        ...

    @abaqus_method_doc
    def getBoundingBox(self):
        """This method returns a dictionary of two tuples representing minimum and maximum boundary
        values of the bounding box of the minimum size containing the element sequence.

        Returns
        -------
        typing.Dict[str, typing.Tuple[float, float, float]]
            A Dictionary object with the following items:
            
            - **low**: a tuple of three floats representing the minimum x, y, and z boundary values of
              the bounding box.
            - **high**: a tuple of three floats representing the maximum x, y, and z boundary values of
              the bounding box.
        """
        ...

    @abaqus_method_doc
    def sequenceFromLabels(self, labels: tuple):
        """This method returns the objects in the MeshElementArray identified using the specified
        labels.

        Parameters
        ----------
        labels
            A sequence of Ints specifying the labels.

        Returns
        -------
        MeshElementArray
            A :py:class:`~abaqus.Mesh.MeshElementArray.MeshElementArray` object.

        Raises
        ------
        Error: The mask results in an empty sequence
            An exception occurs if the resulting sequence is empty.
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class TextStyle:
    """The TextStyle object is used to store the text properties to be used for drawing XY-plot
    text objects.
    TextStyle objects are automatically created when creating a chart or can be created with
    methods described below.

    .. note:: 
        This object can be accessed by::

            import visualization
            session.charts[name].axes1[i].labelStyle
            session.charts[name].axes1[i].titleStyle
            session.charts[name].axes2[i].labelStyle
            session.charts[name].axes2[i].titleStyle
            session.charts[name].legend.textStyle
            session.charts[name].legend.titleStyle
            session.charts[name].tagTextStyle
            session.defaultChartOptions.defaultAxis1Options.labelStyle
            session.defaultChartOptions.defaultAxis1Options.titleStyle
            session.defaultChartOptions.defaultAxis2Options.labelStyle
            session.defaultChartOptions.defaultAxis2Options.titleStyle
            session.defaultChartOptions.legend.textStyle
            session.defaultChartOptions.legend.titleStyle
            session.defaultChartOptions.tagTextStyle
            session.defaultPlot.title.titleStyle
            session.xyPlots[name].charts[name].axes1[i].labelStyle
            session.xyPlots[name].charts[name].axes1[i].titleStyle
            session.xyPlots[name].charts[name].axes2[i].labelStyle
            session.xyPlots[name].charts[name].axes2[i].titleStyle
            session.xyPlots[name].charts[name].legend.textStyle
            session.xyPlots[name].charts[name].legend.titleStyle
            session.xyPlots[name].charts[name].tagTextStyle
            session.xyPlots[name].title.titleStyle
    """

    #: A String specifying the color to be used when drawing text with this TextStyle object.
    #: The default value is "White".
    color: str = ""

    #: A Boolean specifying whether to draw the text when using this TextStyle object. The
    #: default value is ON.
    show: Boolean = ON

    #: A String specifying the name of the font to be used when drawing text with this
    #: TextStyle object. The default value is "-*-verdana-medium-r-normal-*-*-120-*-*-p-*-*-*".
    font: str = ""

    #: A Float specifying the angle in degrees used for displaying the text. The default value
    #: is 0.0.
    rotationAngle: float = 0

    @abaqus_method_doc
    def __init__(
        self,
        color: str = "",
        show: Boolean = ON,
        font: str = "",
        rotationAngle: float = 0,
    ):
        """This method creates a TextStyle.

        .. note:: 
            This function can be accessed by::

                session.TextStyle
                xyPlot.TextStyle

        Parameters
        ----------
        color
            A String specifying the color to be used when drawing text with this TextStyle object.
            The default value is "White".
        show
            A Boolean specifying whether to draw the text when using this TextStyle object. The
            default value is ON.
        font
            A String specifying the name of the font to be used when drawing text with this
            TextStyle object. The default value is "-*-verdana-medium-r-normal-*-*-120-*-*-p-*-*-*".
        rotationAngle
            A Float specifying the angle in degrees used for displaying the text. The default value
            is 0.0.

        Returns
        -------
        TextStyle
            A :py:class:`~abaqus.XY.TextStyle.TextStyle` object.

        Raises
        ------
        ColorError
        """
        ...

    @abaqus_method_doc
    def setValues(
        self,
        color: str = "",
        show: Boolean = ON,
        font: str = "",
        rotationAngle: float = 0,
    ):
        """This method modifies the TextStyle object.

        Parameters
        ----------
        color
            A String specifying the color to be used when drawing text with this TextStyle object.
            The default value is "White".
        show
            A Boolean specifying whether to draw the text when using this TextStyle object. The
            default value is ON.
        font
            A String specifying the name of the font to be used when drawing text with this
            TextStyle object. The default value is "-*-verdana-medium-r-normal-*-*-120-*-*-p-*-*-*".
        rotationAngle
            A Float specifying the angle in degrees used for displaying the text. The default value
            is 0.0.
        """
        ...



from __future__ import annotations

from typing import Any, Union

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .AbaqusBoolean import AbaqusBoolean


@abaqus_class_doc
class SymbolicConstant(str):
    """The SymbolicConstant object represents a string in a way that can be stored in a replay
    file and used as an argument to Abaqus Scripting Interface methods and functions. By
    convention the string representation of the SymbolicConstant object is the same as its
    variable name. If you pass a SymbolicConstant object to the Python repr() function, the
    function returns the text without quotes. In effect, the text is the variable that, by
    convention, refers to the SymbolicConstant object.
    Two SymbolicConstant objects with the same text are the same Python object, although you
    can assign them to different variables. All of the SymbolicConstant objects that are
    required in Abaqus Scripting Interface methods are defined in the abaqusConstants
    module. Some SymbolicConstant objects and the SymbolicConstant constructor are defined
    in the abaqus module. The SymbolicConstant constructor is also defined in the
    symbolicConstants module.

    .. note:: 
        This object can be accessed by::

            from symbolicConstants import *
            from abaqusConstants import *
    """

    @abaqus_method_doc
    def __init__(self, text: str) -> None:
        """The SymbolicConstant method creates a SymbolicConstant object.

        .. note:: 
            This function can be accessed by::

                SymbolicConstant

        Parameters
        ----------
        text
            A String specifying the text of the SymbolicConstant object. The String must contain
            only capital letters, digits, or underscores and must not start with a digit.

        Returns
        -------
        SymbolicConstant
            A :py:class:`~abaqus.UtilityAndView.SymbolicConstant.SymbolicConstant` object.
        """
        if not text.isupper() or not text.isidentifier():
            raise ValueError(f'SymbolicConstant name {text} may only contain upper case, digit or underscore')
        self.text = text

    @abaqus_method_doc
    def __copy__(self) -> SymbolicConstant:
        ...
    
    def __getstate__(self) -> str:
        return self.text
    
    def __hash__(self) -> int:
        ...
    
    def __lt__(self, other: Any) -> bool:
        """Sorting method; True if self is < other"""
        return self < other
    
    @abaqus_method_doc
    def __reduce__(self) -> tuple:  # known return case of __reduce__
        ...
    
    def __repr__(self) -> str: 
        return self.getText()
    
    def __setstate__(self, *args) -> None:
        ...
    
    def __str__(self) -> str:
        return self.text
    
    def getId(self) -> int:
        ...
    
    def getText(self) -> str:
        return self.text
    
    @staticmethod 
    def __new__(cls, name: str, *args, **kargs) -> Union[SymbolicConstant,AbaqusBoolean]:
        if name == "ON":
            return AbaqusBoolean(1)
        elif name == "OFF":
            return AbaqusBoolean(0)
        else:
            return super().__new__(cls)
    
    @classmethod
    def _addToCache(cls, *args, **kwargs):  # real signature unknown
        """
        Helper method for __new__
        Also used by AbaqusBoolean.__new__
        """
        pass

    __weakref__ = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default
    """list of weak references to the object (if defined)"""


from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .RebarLayers import RebarLayers
from .Section import Section
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class SurfaceSection(Section):
    """The SurfaceSection object defines the properties of a surface section.
    The SurfaceSection object is derived from the Section object.

    .. note:: 
        This object can be accessed by::

            import section
            mdb.models[name].sections[name]
            import odbSection
            session.odbs[name].sections[name]

        The corresponding analysis keywords are:

        - SURFACE SECTION
    """

    #: A :py:class:`~abaqus.Section.RebarLayers.RebarLayers` object specifying reinforcement properties.
    rebarLayers: RebarLayers = None

    #: A String specifying the repository key.
    name: str

    #: A Boolean specifying whether or not to use the value of **density**. The default value is
    #: OFF.
    useDensity: Boolean = OFF

    #: A Float specifying the value of density to apply to this section. The default value is
    #: 0.0.
    density: float = 0

    @abaqus_method_doc
    def __init__(self, name: str, useDensity: Boolean = OFF, density: float = 0):
        """This method creates a SurfaceSection object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].SurfaceSection
                session.odbs[name].SurfaceSection

        Parameters
        ----------
        name
            A String specifying the repository key.
        useDensity
            A Boolean specifying whether or not to use the value of **density**. The default value is
            OFF.
        density
            A Float specifying the value of density to apply to this section. The default value is
            0.0.

        Returns
        -------
        SurfaceSection
            A :py:class:`~abaqus.Section.SurfaceSection.SurfaceSection` object.

        Raises
        ------
        RangeError and InvalidNameError
        """
        super().__init__()



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from ...Ratios import Ratios
from ....UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class Swelling:
    """The Swelling object specifies time-dependent volumetric swelling for a material.

    .. note:: 
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].swelling
            import odbMaterial
            session.odbs[name].materials[name].swelling

        The table data for this object are:

        - Volumetric swelling strain rate.
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - SWELLING
    """

    #: A :py:class:`~abaqus.Material.Ratios.Ratios` object.
    ratios: Ratios = Ratios(((),))

    @abaqus_method_doc
    def __init__(
        self,
        table: tuple,
        law: SymbolicConstant = INPUT,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
    ):
        """This method creates a Swelling object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].materials[name].Swelling
                session.odbs[name].materials[name].Swelling

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.This argument is
            valid only when **law** = INPUT.
        law
            A SymbolicConstant specifying the type of data defining the swelling behavior. Possible
            values are INPUT and USER. The default value is INPUT.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0.

        Returns
        -------
        Swelling
            A :py:class:`~abaqus.Material.Plastic.Swelling.Swelling.Swelling` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Swelling object.

        Raises
        ------
        RangeError
        """
        ...



import typing

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .ConstrainedSketchGeometry import ConstrainedSketchGeometry


@abaqus_class_doc
class FilletByRadius(ConstrainedSketchGeometry):
    @abaqus_method_doc
    def __init__(
        self,
        radius: float,
        curve1: "ConstrainedSketchGeometry",
        nearPoint1: typing.Tuple[float, ...],
        curve2: "ConstrainedSketchGeometry",
        nearPoint2: typing.Tuple[float, ...],
    ):
        """This method constructs a fillet arc of a given radius between two curves. The fillet is
        added to the geometry repository of the ConstrainedSketch object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].sketches[name].FilletByRadius

        Parameters
        ----------
        radius
            A Float specifying the radius of the fillet arc. Possible values are Floats > 0.
        curve1
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object specifying the first curve.
        nearPoint1
            A pair of Floats specifying a point on the sketch near where the user wishes the fillet
            to intersect with **curve1**. This point does not need to be on*curve1*; it is used as a
            hint to draw the fillet.
        curve2
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object specifying the second curve.
        nearPoint2
            A pair of Floats specifying a point on the sketch near where the user wishes the fillet
            to intersect with **curve2**. This point does not need to be on **curve2**; it is used as a
            hint to draw the fillet.

        Returns
        -------
        ConstrainedSketchGeometry
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object (None if the fillet cannot be created).

        Raises
        ------
        Range Error: cannot construct the Fillet specified
            If the radius given cannot be used to create a fillet between the two curves given.
        """
        ...



from abqpy.decorators import abaqus_class_doc


@abaqus_class_doc
class RayleighDampingComponent:
    """A :py:class:`~abaqus.StepMiscellaneous.RayleighDampingComponent.RayleighDampingComponent` object is used to define Rayleigh damping over a range of
    modes.

    .. note:: 
        This object can be accessed by::

            import step
            mdb.models[name].steps[name].rayleighDamping.components[i]
    """

    #: An Int specifying the mode number of the lowest mode of a range.
    start: int = None

    #: An Int specifying the mode number of the highest mode of a range.
    end: int = None

    #: A Float specifying the mass proportional damping, αM.
    alpha: float = None

    #: A Float specifying the stiffness proportional damping, βM.
    beta: float = None



import typing

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .HistoryPoint import HistoryPoint
from .HistoryRegion import HistoryRegion
from .OdbFrame import OdbFrame
from .OdbLoadCase import OdbLoadCase
from .OdbStepBase import OdbStepBase


@abaqus_class_doc
class OdbStep(OdbStepBase):
    @abaqus_method_doc
    def HistoryRegion(
        self, name: str, description: str, point: HistoryPoint, loadCase: str = None
    ) -> HistoryRegion:
        """This method creates a HistoryRegion object.

        .. note:: 
            This function can be accessed by::

                session.odbs[name].steps[name].HistoryRegion

        Parameters
        ----------
        name
            A String specifying the name of the HistoryRegion object.
        description
            A String specifying the description of the HistoryRegion object.
        point
            A :py:class:`~abaqus.Odb.HistoryPoint.HistoryPoint` object specifying the point to which the history data refer.
        loadCase
            None or an OdbLoadCase object specifying the load case associated with the HistoryRegion
            object. The default value is None.

        Returns
        -------
        HistoryRegion
            A :py:class:`~abaqus.Odb.HistoryRegion.HistoryRegion` object.
        """
        self.historyRegions[name] = historyRegion = HistoryRegion(
            name, description, point, loadCase
        )
        return historyRegion

    @typing.overload
    @abaqus_method_doc
    def Frame(
        self, incrementNumber: int, frameValue: float, description: str = ""
    ) -> OdbFrame:
        """This method creates an OdbFrame object and appends it to the frame sequence.

        .. note:: 
            This function can be accessed by::

                session.odbs[name].steps[name].Frame

        Parameters
        ----------
        incrementNumber
            An Int specifying the frame increment number within the step. The base frame has
            normally increment number 0, and the results run from 1. In case of multiple load cases,
            the same increment number is duplicated for each load case.
        frameValue
            A Float specifying the value in units determined by the **domain** member of the Step
            object. The equivalent in the time domain is **stepTime**; in the frequency domain the
            equivalent is **frequency**; and in the modal domain the equivalent is **mode**.
        description
            A String specifying the contents of the frame. The default value is an empty string.

        Returns
        -------
        OdbFrame
            An :py:class:`~abaqus.Odb.OdbFrame.OdbFrame` object.
        """
        ...

    @typing.overload
    @abaqus_method_doc
    def Frame(self, mode: int, frequency: float, description: str = "") -> OdbFrame:
        """This constructor creates an OdbFrame object in the frequency domain and appends it to
        the frame sequence. The arguments to the constructor are valid only when
        **domain** = FREQUENCY or **domain** = MODAL.

        .. note:: 
            This function can be accessed by::

                session.odbs[name].steps[name].Frame

        Parameters
        ----------
        mode
            An Int specifying the eigenmode. This member is valid only if **domain** = MODAL.
        frequency
            A Float specifying the frequency. This member is valid only if **domain** = FREQUENCY or if
            the **procedureType** member of the Step object=FREQUENCY. The default value is 0.0.
        description
            A String specifying the contents of the frame. The default value is an empty string.

        Returns
        -------
        OdbFrame
            An :py:class:`~abaqus.Odb.OdbFrame.OdbFrame` object.
        """
        ...

    @typing.overload
    @abaqus_method_doc
    def Frame(
        self, loadCase: OdbLoadCase, description: str = "", frequency: float = 0
    ) -> OdbFrame:
        """This constructor creates an OdbFrame object for a specific load case and appends it to
        the frame sequence.

        .. note:: 
            This function can be accessed by::

                session.odbs[name].steps[name].Frame

        Parameters
        ----------
        loadCase
            An :py:class:`~abaqus.Odb.OdbLoadCase.OdbLoadCase` object specifying the load case for the frame.
        description
            A String specifying the contents of the frame. The default value is an empty string.
        frequency
            A Float specifying the frequency. This member is valid only if **domain** = FREQUENCY or if
            the **procedureType** member of the Step object=FREQUENCY. The default value is 0.0.

        Returns
        -------
        OdbFrame
            An :py:class:`~abaqus.Odb.OdbFrame.OdbFrame` object.
        """
        ...

    @abaqus_method_doc
    def Frame(self, *args, **kwargs) -> OdbFrame:
        frame = OdbFrame(*args, **kwargs)
        self.frames.append(frame)
        return frame

    def LoadCase(self, name: str) -> OdbLoadCase:
        """This method creates an OdbLoadCase object.

        .. note:: 
            This function can be accessed by::

                session.odbs[name].steps[name].LoadCase

        Parameters
        ----------
        name
            A String specifying the name of the OdbLoadCase object.

        Returns
        -------
        OdbLoadCase
            An :py:class:`~abaqus.Odb.OdbLoadCase.OdbLoadCase` object.
        """
        self.loadCases[name] = odbLoadCase = OdbLoadCase(name)
        return odbLoadCase



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .ConstrainedSketchConstraint import ConstrainedSketchConstraint
from ..ConstrainedSketchGeometry.ConstrainedSketchGeometry import (
    ConstrainedSketchGeometry,
)


@abaqus_class_doc
class EqualLengthConstraint(ConstrainedSketchConstraint):
    @abaqus_method_doc
    def __init__(
        self, entity1: ConstrainedSketchGeometry, entity2: ConstrainedSketchGeometry
    ):
        """This method creates an equal length constraint. This constraint applies to lines and
        constrains them such that their lengths are equal.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].sketches[name].EqualLengthConstraint

        Parameters
        ----------
        entity1
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object specifying the first line.
        entity2
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry` object specifying the second line.

        Returns
        -------
        ConstrainedSketchConstraint
            A :py:class:`~abaqus.Sketcher.ConstrainedSketchConstraint.ConstrainedSketchConstraint.ConstrainedSketchConstraint` object.

        """
        ...



import typing

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .Amplitude import Amplitude
from .BaselineCorrection import BaselineCorrection
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class TabularAmplitude(Amplitude):
    """The TabularAmplitude object defines an amplitude curve as a table of values at
    convenient points on the time scale.
    The TabularAmplitude object is derived from the Amplitude object.

    .. note:: 
        This object can be accessed by::

            import amplitude
            mdb.models[name].amplitudes[name]
            import odbAmplitude
            session.odbs[name].amplitudes[name]

        The corresponding analysis keywords are:

        - AMPLITUDE
    """

    #: A :py:class:`~abaqus.Amplitude.BaselineCorrection.BaselineCorrection` object.
    baselineCorrection: BaselineCorrection = BaselineCorrection()

    #: A String specifying the repository key.
    name: str

    #: A sequence of pairs of Floats specifying time/frequency and amplitude pairs. Possible
    #: values for time/frequency are positive numbers.
    data: tuple

    #: The SymbolicConstant SOLVER_DEFAULT or a Float specifying the degree of smoothing.
    #: Possible float values are between 0 and 0.5. If **smooth** = SOLVER_DEFAULT, the default
    #: degree of smoothing will be determined by the solver. The default value is
    #: SOLVER_DEFAULT.
    smooth: typing.Union[SymbolicConstant, float] = SOLVER_DEFAULT

    #: A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP
    #: and TOTAL. The default value is STEP.
    timeSpan: SymbolicConstant = STEP

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        data: tuple,
        smooth: typing.Union[SymbolicConstant, float] = SOLVER_DEFAULT,
        timeSpan: SymbolicConstant = STEP,
    ):
        """This method creates a TabularAmplitude object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].TabularAmplitude
                session.odbs[name].TabularAmplitude

        Parameters
        ----------
        name
            A String specifying the repository key.
        data
            A sequence of pairs of Floats specifying time/frequency and amplitude pairs. Possible
            values for time/frequency are positive numbers.
        smooth
            The SymbolicConstant SOLVER_DEFAULT or a Float specifying the degree of smoothing.
            Possible float values are between 0 and 0.5. If **smooth** = SOLVER_DEFAULT, the default
            degree of smoothing will be determined by the solver. The default value is
            SOLVER_DEFAULT.
        timeSpan
            A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP
            and TOTAL. The default value is STEP.

        Returns
        -------
        TabularAmplitude
            A :py:class:`~abaqus.Amplitude.TabularAmplitude.TabularAmplitude` object.

        Raises
        ------
        InvalidNameError
        RangeError
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        smooth: typing.Union[SymbolicConstant, float] = SOLVER_DEFAULT,
        timeSpan: SymbolicConstant = STEP,
    ):
        """This method modifies the TabularAmplitude object.

        Parameters
        ----------
        smooth
            The SymbolicConstant SOLVER_DEFAULT or a Float specifying the degree of smoothing.
            Possible float values are between 0 and 0.5. If **smooth** = SOLVER_DEFAULT, the default
            degree of smoothing will be determined by the solver. The default value is
            SOLVER_DEFAULT.
        timeSpan
            A SymbolicConstant specifying the time span of the amplitude. Possible values are STEP
            and TOTAL. The default value is STEP.

        Raises
        ------
        RangeError
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from .GeometricRestriction import GeometricRestriction
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class PenetrationCheck(GeometricRestriction):
    """The PenetrationCheck object defines a penetration check geometric restriction.
    The PenetrationCheck object is derived from the GeometricRestriction object.
    This page discusses:

    .. note:: 
        This object can be accessed by::

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the penetration check region.
    penetrationCheckRegion: Region

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
    #: When used with a TopologyTask, there is no default value. When used with a ShapeTask,
    #: the default value is MODEL.
    region: Region

    #: A Boolean specifying whether to ignore the geometric restriction in the first design
    #: cycle. The default value is ON.
    presumeFeasibleRegionAtStart: Boolean = ON

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        penetrationCheckRegion: Region,
        region: Region,
        presumeFeasibleRegionAtStart: Boolean = ON,
    ):
        """This method creates a PenetrationCheck object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].optimizationTasks[name].PenetrationCheck

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        penetrationCheckRegion
            A :py:class:`~abaqus.Region.Region.Region` object specifying the penetration check region.
        region
            A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the geometric restriction is applied.
            When used with a TopologyTask, there is no default value. When used with a ShapeTask,
            the default value is MODEL.
        presumeFeasibleRegionAtStart
            A Boolean specifying whether to ignore the geometric restriction in the first design
            cycle. The default value is ON.

        Returns
        -------
        PenetrationCheck
            A :py:class:`~abaqus.Optimization.PenetrationCheck.PenetrationCheck` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, presumeFeasibleRegionAtStart: Boolean = ON):
        """This method modifies the PenetrationCheck object.

        Parameters
        ----------
        presumeFeasibleRegionAtStart
            A Boolean specifying whether to ignore the geometric restriction in the first design
            cycle. The default value is ON.
        """
        ...



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class ContactTangentialBehavior:
    """The ContactTangentialBehavior object specifies tangential behavior for a contact
    interaction property.

    .. note:: 
        This object can be accessed by::

            import interaction
            mdb.models[name].interactionProperties[name].tangentialBehavior

        The table data for this object are:

        - If **formulation** = PENALTY or LAGRANGE, the table data specify the following:
        
            - Friction coefficient in the first slip direction, μ1μ1.
            - Friction coefficient in the second slip direction, μ2μ2 (if **directionality** = ANISOTROPIC).
            - Slip rate, if the data depend on slip rate.
            - Contact pressure, if the data depend on contact pressure.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **formulation** = EXPONENTIAL_DECAY and **exponentialDecayDefinition** = COEFFICIENTS, the table data specify the following:
        
            - Static friction coefficient.
            - Kinetic friction coefficient.
            - Decay coefficient.
        - If **formulation** = EXPONENTIAL_DECAY and **exponentialDecayDefinition** = TEST_DATA, the table data specify the following:
        
            - Friction coefficient.
            - Slip rate.
        - If **formulation** = USER_DEFINED, the table data specify the following:
        
            - Friction property.

        The corresponding analysis keywords are:

        - FRICTION
        - CHANGE FRICTION
    """

    #: A SymbolicConstant specifying the friction formulation. Possible values are
    #: FRICTIONLESS, PENALTY, EXPONENTIAL_DECAY, ROUGH, LAGRANGE, and USER_DEFINED. The default
    #: value is FRICTIONLESS.
    formulation: SymbolicConstant = FRICTIONLESS

    #: A SymbolicConstant specifying the directionality of the friction. Possible values are
    #: ISOTROPIC and ANISOTROPIC. The default value is ISOTROPIC.
    directionality: SymbolicConstant = ISOTROPIC

    #: A Boolean specifying whether the data depend on slip rate. The default value is OFF.
    slipRateDependency: Boolean = OFF

    #: A Boolean specifying whether the data depend on contact pressure. The default value is
    #: OFF.
    pressureDependency: Boolean = OFF

    #: A Boolean specifying whether the data depend on temperature. The default value is OFF.
    temperatureDependency: Boolean = OFF

    #: An Int specifying the number of field variables. The default value is 0.
    dependencies: int = 0

    #: A SymbolicConstant specifying the exponential decay definition. Possible values are
    #: COEFFICIENTS and TEST_DATA. The default value is COEFFICIENTS.
    exponentialDecayDefinition: SymbolicConstant = COEFFICIENTS

    #: None or a Float specifying the shear stress limit. If **shearStressLimit** = None, there is
    #: no upper limit. The default value is None.
    shearStressLimit: float = None

    #: A SymbolicConstant specifying what the maximum elastic slip will be. Possible values are
    #: FRACTION and ABSOLUTE_DISTANCE. The default value is FRACTION.
    maximumElasticSlip: SymbolicConstant = FRACTION

    #: A Float specifying the fraction of a characteristic surface dimension. The default value
    #: is 0.0.
    fraction: float = 0

    #: A Float specifying the absolute distance. The default value is 0.0.
    absoluteDistance: float = 0

    #: None or a Float specifying the elastic slip stiffness. If **elasticSlipStiffness** = None,
    #: there is no upper limit. The default value is None.
    elasticSlipStiffness: float = None

    #: An Int specifying the number of state-dependent variables. The default value is 0.
    nStateDependentVars: int = 0

    #: A Boolean specifying whether property values will be used. The default value is OFF.
    useProperties: Boolean = OFF

    #: A tuple of tuples of Floats specifying tangential behavior. The items in the table data
    #: are described below.
    table: float = None

    @abaqus_method_doc
    def __init__(
        self,
        formulation: SymbolicConstant = FRICTIONLESS,
        directionality: SymbolicConstant = ISOTROPIC,
        slipRateDependency: Boolean = OFF,
        pressureDependency: Boolean = OFF,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        exponentialDecayDefinition: SymbolicConstant = COEFFICIENTS,
        table: tuple = (),
        shearStressLimit: float = None,
        maximumElasticSlip: SymbolicConstant = FRACTION,
        fraction: float = 0,
        absoluteDistance: float = 0,
        elasticSlipStiffness: float = None,
        nStateDependentVars: int = 0,
        useProperties: Boolean = OFF,
    ):
        """This method creates a ContactTangentialBehavior object.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].interactionProperties[name].TangentialBehavior

        Parameters
        ----------
        formulation
            A SymbolicConstant specifying the friction formulation. Possible values are
            FRICTIONLESS, PENALTY, EXPONENTIAL_DECAY, ROUGH, LAGRANGE, and USER_DEFINED. The default
            value is FRICTIONLESS.
        directionality
            A SymbolicConstant specifying the directionality of the friction. Possible values are
            ISOTROPIC and ANISOTROPIC. The default value is ISOTROPIC.
        slipRateDependency
            A Boolean specifying whether the data depend on slip rate. The default value is OFF.
        pressureDependency
            A Boolean specifying whether the data depend on contact pressure. The default value is
            OFF.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variables. The default value is 0.
        exponentialDecayDefinition
            A SymbolicConstant specifying the exponential decay definition. Possible values are
            COEFFICIENTS and TEST_DATA. The default value is COEFFICIENTS.
        table
            A sequence of sequences of Floats specifying tangential behavior. The items in the table
            data are described below.
        shearStressLimit
            None or a Float specifying the shear stress limit. If **shearStressLimit** = None, there is
            no upper limit. The default value is None.
        maximumElasticSlip
            A SymbolicConstant specifying what the maximum elastic slip will be. Possible values are
            FRACTION and ABSOLUTE_DISTANCE. The default value is FRACTION.
        fraction
            A Float specifying the fraction of a characteristic surface dimension. The default value
            is 0.0.
        absoluteDistance
            A Float specifying the absolute distance. The default value is 0.0.
        elasticSlipStiffness
            None or a Float specifying the elastic slip stiffness. If **elasticSlipStiffness** = None,
            there is no upper limit. The default value is None.
        nStateDependentVars
            An Int specifying the number of state-dependent variables. The default value is 0.
        useProperties
            A Boolean specifying whether property values will be used. The default value is OFF.

        Returns
        -------
        ContactTangentialBehavior
            A :py:class:`~abaqus.Interaction.ContactTangentialBehavior.ContactTangentialBehavior` object.
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the ContactTangentialBehavior object."""
        ...



import os
import sys


def run(cae: bool = True, exit_after: bool = True) -> None:
    """Runs Abaqus command in system's CLI
    
    This function uses the top level script file to run the Abaqus
    command, and the arguments passed to it
    
    Parameters
    ----------
    cae : bool, optional
        Wether or not to use `abaqus cae` command or
        `abaqus python`, by default True
    exit_after : bool, optional
        Wether to exit of the Python3 interpreter
        after calling Abaqus, by default False
    """
    abaqus = os.environ.get("ABAQUS_BAT_PATH", "abaqus")
    filePath = os.path.abspath(sys.modules['__main__'].__file__)
    args = " ".join(sys.argv[1:])

    try:  # If it is a jupyter notebook
        import ipynbname
        filePath = ipynbname.path()
        os.system(f"jupyter nbconvert --to python {filePath}")
        filePath = str(filePath).replace(".ipynb", ".py")
    except (FileNotFoundError, ImportError, Exception):
        pass
    if cae:
        os.system(f"{abaqus} cae noGUI={filePath} -- {args}")
    else:
        os.system(f"{abaqus} python {filePath} {args}")
    if exit_after:
        sys.exit(0)



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class Restart:
    """The Restart object defines a restart request.

    .. note:: 
        This object can be accessed by::

            import step
            mdb.models[name].steps[name].restart

        The corresponding analysis keywords are:

        - RESTART
    """

    #: An Int specifying the number of intervals during the step at which restart information
    #: will be written. The default value is 0. The default value is 1.
    numberIntervals: int = 0

    #: A Boolean specifying whether to use exact time marks for writing during an analysis. The
    #: default value is OFF. The default value is OFF.
    timeMarks: Boolean = OFF

    #: A Boolean specifying that only one increment per step should be retained on the restart
    #: file, thus minimizing the size of the restart file. The default value is OFF. The
    #: default value is ON.
    overlay: Boolean = OFF

    #: An Int specifying the increments at which restart information will be written. The
    #: default value is 0. The default value is 0.This argument applies only to Abaqus/Standard
    #: analyses.
    frequency: int = 0

    @abaqus_method_doc
    def __init__(
        self,
        numberIntervals: int = 0,
        timeMarks: Boolean = OFF,
        overlay: Boolean = OFF,
        frequency: int = 0,
    ):
        """This method creates a restart request.

        .. note:: 
            This function can be accessed by::

                mdb.models[name].steps[name].Restart

        Parameters
        ----------
        numberIntervals
            An Int specifying the number of intervals during the step at which restart information
            will be written. The default value is 0. The default value is 1.
        timeMarks
            A Boolean specifying whether to use exact time marks for writing during an analysis. The
            default value is OFF. The default value is OFF.
        overlay
            A Boolean specifying that only one increment per step should be retained on the restart
            file, thus minimizing the size of the restart file. The default value is OFF. The
            default value is ON.
        frequency
            An Int specifying the increments at which restart information will be written. The
            default value is 0. The default value is 0.This argument applies only to Abaqus/Standard
            analyses.

        Returns
        -------
        Restart
            A :py:class:`~abaqus.StepOutput.Restart.Restart` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Restart object.

        Raises
        ------
        RangeError
        """
        ...



import abqpy.abaqus
from abaqus.Odb.OdbCommands import *
from abaqus.UtilityAndView.BackwardCompatibility import BackwardCompatibility
from abaqus.Odb.OdbSequenceAnalyticSurfaceSegment import OdbSequenceAnalyticSurfaceSegment


def openOdb(path: str, readOnly: Boolean = OFF, readInternalSets: Boolean = OFF) -> Odb:
    """This method opens an existing output database (`.odb`) file and creates a new Odb object.
    You typically execute this method outside of Abaqus/CAE when, in most cases, only one
    output database is open at any time. For example::
    
        import odbAccess
        shockLoadOdb = odbAccess.openOdb(path='myOdb.odb')

    Parameters
    ----------
    path
        A String specifying the path to an existing output database (`.odb`) file.
    readOnly
        A Boolean specifying whether the file will permit only read access or both read and
        write access. The initial value is `False`, indicating that both read and write access
        will be permitted.
    readInternalSets
        A Boolean specifying whether the file will permit access to sets specified as Internal
        on the database. The initial value is `False`, indicating that internal sets will not be
        read.

    Returns
    -------
    Odb
        An :py:class:`~abaqus.Odb.Odb.Odb` object.

    Raises
    ------
    OdbError: The database is from a previous release of Abaqus.
        If the output database was generated by a previous release of Abaqus and needs
        upgrading. Run `abaqus upgrade -job <newFilename> -odb <oldFileName>` to upgrade it.
    OdbError: Abaqus installation must be upgraded before this output database can be
    opened.
        If the output database was generated by a newer release of Abaqus, and the
        installation of Abaqus needs upgrading.
          
    """
    abqpy.abaqus.run(cae=False)
    return Odb(path)


def AnalyticSurfaceProfile() -> OdbSequenceAnalyticSurfaceSegment:
    """This method creates a OdbSequenceAnalyticSurfaceSegment object.
    
    Returns
    -------
    OdbSequenceAnalyticSurfaceSegment
        An :py:class:`~abaqus.Odb.OdbSequenceAnalyticSurfaceSegment.OdbSequenceAnalyticSurfaceSegment` object.
    """
    return OdbSequenceAnalyticSurfaceSegment()


backwardCompatibility = BackwardCompatibility()



from abqpy.decorators import abaqus_class_doc
from .InteractionState import InteractionState
from ..UtilityAndView.abaqusConstants import *


@abaqus_class_doc
class StdXplCosimulationState(InteractionState):
    """The StdXplCosimulationState object stores the propagating data for a StdXplCosimulation
    object. One instance of this object is created internally by the StdXplCosimulation
    object for each step. The instance is also deleted internally by the StdXplCosimulation
    object.
    The StdXplCosimulationState object has no constructor or methods.
    The StdXplCosimulationState object is derived from the InteractionState object.

    .. note:: 
        This object can be accessed by::

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

        The corresponding analysis keywords are:

        - CO-SIMULATION
                - CO-SIMULATION REGION
                - CO-SIMULATION CONTROLS
    """

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None
